import { Platforms } from "@/meta/settings";
import axios from "axios";

type GetParams = {
  params: {
    platform: Platforms
    encodedUrl: string
  };
};

export async function GET(req: Request, { params }: GetParams) {

  const { platform, encodedUrl } = params;

  if (!Object.keys(Platforms).includes(platform)) {
    return Response.json(
      { 
        success: false, 
        message: 'Platform not supported!' 
      },
      { status: 404 }
    )
  }

  const decodedUrl = decodeURIComponent(encodedUrl)
  
  const response = await axios.get<ReadableStream>(decodedUrl, {
    responseType: "stream",
  });

  return new Response(response.data);
}

